﻿/*******************************************************************************
File        : Program.cs
Description : 
--------------------------------------------------------------------------------
Functions:
--------------------------------------------------------------------------------
History:
2011/05/17 TPR Created
*******************************************************************************/
using System;
using Wiker.WIDatabase;
using System.Text;

namespace ErrorChecking
{
   class Program
   {
      /*******************************************************************************
      Function    : Main()
      Description : 
      Parameters  : string[] args - 
      Returns     : void
      --------------------------------------------------------------------------------
      History:
      2011/05/17 TPR Created
      *******************************************************************************/
      static void Main(string[] args)
      {  
         WIDBUtil DBUtil;
         StringBuilder StrB,StrR;
         CDatabaseInfo DBInfo;
         string Str;
         
         /* Create DatabaseInfo object with login info  */
         DBInfo = new CDatabaseInfo();
         DBInfo.DatabaseType = eDatabaseType.SQLite;
         DBInfo.Location =  "\\WIDatabase\\Samples";
         DBInfo.DBName = "SQLite.db3";         
         DBInfo.Password = "";
         DBInfo.Port = 0;
         DBInfo.Username = "";

         StrB = new StringBuilder();
         DBUtil = null;
         try
         {
            /* Create Connection To Database */
            DBUtil = new WIDBUtil(DBInfo);

            /* make sure there was no error creting the object */
            if (DBUtil.LastError != eDBErrorCodes.None)
               {
               Str = string.Format("Failed to open database\n{0}\nLastError = {1}", DBInfo.DBName,DBUtil.LastError.ToString());
               Console.WriteLine(Str);
               return;
               }

            /* Build the select statement based on DatabaseType */
            switch (DBUtil.DatabaseType)
               {
               /* Requires different syntax vs. MySql/SQLite */
               case eDatabaseType.SQL:               
                  StrB.Append("SELECT TOP 10 AddressID, Address1, Address2, City, State, ZipCode ");
                  StrB.Append("FROM tblAddress;");
               break;

               /* MySql and SQLite are the same statement so the cases collapse together */
               case eDatabaseType.MySql:
               case eDatabaseType.SQLite:
                  StrB.Append("SELECT AddressID, Address1, Address2, City, State, ZipCode ");
                  StrB.Append("FROM tblAddress LIMIT 10;");
               break;

               case eDatabaseType.None:
                  return;
               }

            /* Column list with IDs as guide for readrow() */
            /*
            0  AddressID 
            1  Address1
            2  Address2
            3  City
            4  State
            5  ZipCode
            */

            /* Set the command to be the SQL statement created above */
            DBUtil.CommandText = StrB.ToString();

            /* Open the Connection */
            if (!DBUtil.Open()) /* Open Database */
               {
               Str = string.Format("Failed to open database\nLastError = {0}\n{1}", DBUtil.LastError.ToString(),DBUtil.LastErrorMessage);
               Console.WriteLine(Str);
               return;
               }

            Console.WriteLine("| AddressID | Address1 | Address2 | City | State | Zip |");

            /* Loop thru the returned records */
            while (DBUtil.ReadRow())
               {
               StrR = new StringBuilder();
               /* DBUtil.Read* obtains the value at the column index for that type  */
               StrR.AppendFormat("| {0} ", DBUtil.ReadInt(0));
               StrR.AppendFormat("| {0} ", DBUtil.ReadString(1));
               StrR.AppendFormat("| {0} ", DBUtil.ReadString(2));
               StrR.AppendFormat("| {0} ", DBUtil.ReadString(3));
               StrR.AppendFormat("| {0} ", DBUtil.ReadString(4));
               StrR.AppendFormat("| {0} |", DBUtil.ReadString(5));

               Console.WriteLine(StrR.ToString());
               }

            /* Good practice to colse the connection when finished */
            DBUtil.Close();  
         }
         catch(Exception ex)
         {   
            if (DBUtil != null)
               DBUtil.Close();

            Str = string.Format("LoadCompanyNamesSELECT() Exception\n{0}", ex.Message);
            Console.WriteLine(Str);
            return;         
         }                         
      }
   }/* End Class */
}/* End NameSpace */
